@@ -284,10 +284,11 @@ def get_all(table):
     import pandas as pd
     df = pd.DataFrame(df, columns = list(d))
     return df
-def remove_ENR(i,d,cursor, conn, kwargs):
-    # value = i[d['ministock_name']][:i[d['ministock_name']].index(kwargs['string'])]
-    # print(i[d['ministock_name']])
-    # update = '''UPDATE %s SET %s = '%s' WHERE id = %i;'''%(kwargs['table'],kwargs['column'],value, i[d['id']])
-    # cursor.execute(update)
-    # conn.commit()
-    print(i[d['id']])
+# Example function
+# 
+# def del0(i,d, cursor, conn,kwargs):
+#     '''remove 0 from partials'''
+#     update = '''UPDATE %s SET %s = NULL WHERE id = %i;'''%(kwargs['table'],kwargs['column'], i[d['id']])
+#     cursor.execute(update)
+#     conn.commit()
+#
